@@ -2,7 +2,7 @@ use cosmwasm_std::{QuerierWrapper, StdResult};
 
 use crate::query::{
     CollectionResponse, CudosQuery, DenomResponse, DenomsResponse, OwnerCollectionResponse,
-    QueryNFTResponse, SupplyResponse,
+    QueryNFTResponse, SupplyResponse, QueryApprovalsResponse, QueryApprovedForAllResponse,
 };
 
 pub struct CudosQuerier<'a> {
@@ -41,7 +41,7 @@ impl<'a> CudosQuerier<'a> {
         self.querier.custom_query(&request)
     }
 
-    pub fn query_all_denoms<T: Into<String>>(&self) -> StdResult<DenomsResponse> {
+    pub fn query_denoms<>(&self) -> StdResult<DenomsResponse> {
         let request = CudosQuery::QueryDenoms {}.into();
         self.querier.custom_query(&request)
     }
@@ -64,12 +64,12 @@ impl<'a> CudosQuerier<'a> {
         self.querier.custom_query(&request)
     }
 
-    pub fn query_owner<T: Into<String>>(
+    pub fn query_owner<T: Into<Option<String>>, D: Into<String>>(
         &self,
         denom_id: T,
-        address: T,
+        address: D,
     ) -> StdResult<OwnerCollectionResponse> {
-        let request = CudosQuery::QueryCollectionByOwner {
+        let request = CudosQuery::QueryOwner {
             denom_id: denom_id.into(),
             address: address.into(),
         }
@@ -92,11 +92,11 @@ impl<'a> CudosQuerier<'a> {
         self.querier.custom_query(&request)
     }
 
-    pub fn query_approved_addresses<T: Into<String>>(
+    pub fn query_approvals<T: Into<String>>(
         &self,
         denom_id: T,
         token_id: T,
-    ) -> StdResult<QueryNFTResponse> {
+    ) -> StdResult<QueryApprovalsResponse> {
         let request = CudosQuery::QueryApprovals {
             denom_id: denom_id.into(),
             token_id: token_id.into(),
@@ -105,4 +105,18 @@ impl<'a> CudosQuerier<'a> {
 
         self.querier.custom_query(&request)
     }
+
+    pub fn query_approved_for_all<T: Into<String>>(
+        &self,
+        owner_address: T,
+        operator_address: T,
+    ) -> StdResult<QueryApprovedForAllResponse> {
+        let request = CudosQuery::QueryApprovedForAll {
+            owner_address: owner_address.into(),
+            operator_address: operator_address.into(),
+        }
+        .into();
+
+        self.querier.custom_query(&request)
+    }
 }
